@@ -1,3 +1,3 @@
 from .base import SelectedBackend, SEOBackendBase
 from .prerender import PrerenderHosted, PrerenderIO
-from .test import TestBackend
+from .test import TestBackend, TestServiceDownBackend
